@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous      *
  *                  mode detection and handling.                  *
  *                                                                *
- * Version:         1.0.7                                         *
+ * Version:         1.0.8                                         *
  *                                                                *
  * -------------------------------------------------------------- *
  *                                                                *
@@ -48,6 +48,8 @@
  *                - Checks each value in an ifchk configuration   *
  *                  file keyword/value pair for conformance to an *
  *                  established formal grammer.                   *
+ *                - Sets ifchk configuration file keyword/value   *
+ *                  pairs to define program runtime behavior.     *
  ******************************************************************/
  
 /**********************
@@ -93,6 +95,7 @@ struct conf *loadConfig( char *confFile )
     struct conf *tail = NULL;		/* of config file \ */
     struct conf *new = NULL;		/* keyword/value \ */
     struct conf *cur = NULL;		/* pairs. */
+    int setConf = 0;			/* For setConfig(). */
     char *redefPtr = NULL;		/* Ptr to redefined line. */
     char *cfFile = NULL;		/* Ptr to ifchk configuration file. */
     FILE *conffilefd = NULL;		/* For statFile(). */
@@ -338,10 +341,104 @@ struct conf *loadConfig( char *confFile )
         return (NULL);
      }
 
+    setConf = setConfig( head );
+
     return ( head );
 }
 
 
+/*************************************************************
+ * setConfig() - Sets ifchk configuration file keyword/value *
+ *               pairs.                                      *
+ *                                                           *
+ * Parameters:   *conf: Pointer to a linked list of ifchk    *
+ *                      configuration file parameters.       *
+ *                                                           *
+ * Returns:      0 on success.                               *
+ *               -1 on failure.                              *
+ *************************************************************/
+
+int setConfig( struct conf *conf )
+{
+    int ifStatusSecs = 0;	/* Interface status scan frequency. */
+    int ifMetricSecs = 0;	/* Interface metrics dump frequency. */
+    int disablePromisc = 0;	/* Enable/disable promiscuous interface shutdown. */
+    char *errFile = NULL;	/* Error log file pathname. */
+    char paramBuf[STRBUFSZ];	/* Configuration parameter buffer. */
+    struct conf *cur = NULL;	/* Sanity checked configuration keyword/value pairs. */
+    struct fsObj cfObject;	/* For statFile(). */
+
+    cur = conf;
+
+    /*
+     * Reset all statFile() file checks.
+     */
+    cfObject.openRead = FALSE;
+    cfObject.procLen = FALSE;
+    cfObject.procOwner = FALSE;
+    cfObject.procMode = FALSE;
+    cfObject.regLen = FALSE;
+    cfObject.regMode = FALSE;
+
+    /*
+     * With the file parsed, we can now set our configuration parameters.
+     */
+    while( cur )
+    {
+        memset( paramBuf, '\000', sizeof( paramBuf ) );
+
+        strncpy( paramBuf, cur -> keyword, sizeof( paramBuf ) );
+
+        paramBuf[STRBUFSZ - 1] = '\000';
+
+        /*
+         * errLog - the ifchk error log pathname.
+         */
+        if( ( strncmp( paramBuf, "errLog", sizeof( paramBuf ) ) ) == 0 )
+        {
+            errFile = cur -> value;
+            cfObject.regMode = TRUE;
+         }
+
+        /*
+         * disableOnPromisc - promiscuous interface management policy.
+	 */
+        else if( ( strncmp( paramBuf, "disableOnPromisc", sizeof( paramBuf ) ) ) == 0 )
+        {
+            disablePromisc = atoi( cur -> value );
+         }
+
+        /*
+         * ifStatusDumpFreq - interface status dump frequency.
+         */
+        else if( ( strncmp( paramBuf, "ifStatusDumpFreq", sizeof( paramBuf ) ) ) == 0 )
+        {
+            ifStatusSecs = atoi( cur -> value );
+         }
+
+        /*
+	 * ifMetricDumpFreq - interface metric dump frequency.
+	 */
+        else if( ( strncmp( paramBuf, "ifMetricDumpFreq", sizeof( paramBuf ) ) ) == 0 )
+        {
+            ifMetricSecs = atoi( cur -> value );
+         }
+
+        /*
+         * Default: signals an error condition.
+         */
+        else
+        {
+            exit( EXIT_FAILURE );
+         }
+
+        cur = cur -> next;
+     }
+
+    return (0);
+}
+
+
 /*************************************************************
  * chkRedef() - Flags and reports on redundant keyword/value *
  *              pair entries in an ifchk configuration file. *
