@@ -31,7 +31,7 @@
  * Project ifchk -- Host based network interface promiscuous  *
  *                  mode detection and handling.              *
  *                                                            *
- * Version:         1.0.7                                     *
+ * Version:         1.0.8                                     *
  *                                                            *
  * ---------------------------------------------------------- *
  *                                                            *
@@ -346,59 +346,21 @@ int main( int argc, char **argv )
      }
 
     /*
-     * With the file parsed, we can now load our configuration parameters.
+     * With the file parsed, we can now set our configuration parameters.
      */
-    while( curParam )
-    {
-        memset( paramBuf, '\000', sizeof( paramBuf ) );
+    errFile = curParam -> value;
 
-        strncpy( paramBuf, curParam -> keyword, sizeof( paramBuf ) );
+    curParam = curParam -> next;
 
-        paramBuf[STRBUFSZ - 1] = '\000';
+    disablePromisc = atoi( curParam -> value );
 
-        /*
-         * errLog - the ifchk error log pathname.
-         */
-        if( ( strncmp( paramBuf, "errLog", sizeof( paramBuf ) ) ) == 0 )
-        {
-            errFile = curParam -> value;
-            fsObject.regMode = TRUE;
-         }
+    curParam = curParam -> next ;
 
-        /*
-         * disableOnPromisc - promiscuous interface management policy.
-	 */
-        else if( ( strncmp( paramBuf, "disableOnPromisc", sizeof( paramBuf ) ) ) == 0 )
-        {
-            disablePromisc = atoi( curParam -> value );
-         }
+    ifStatusSecs = atoi( curParam -> value );
 
-        /*
-         * ifStatusDumpFreq - interface status dump frequency.
-         */
-        else if( ( strncmp( paramBuf, "ifStatusDumpFreq", sizeof( paramBuf ) ) ) == 0 )
-        {
-            ifStatusSecs = atoi( curParam -> value );
-         }
+    curParam = curParam -> next;
 
-        /*
-	 * ifMetricDumpFreq - interface metric dump frequency.
-	 */
-        else if( ( strncmp( paramBuf, "ifMetricDumpFreq", sizeof( paramBuf ) ) ) == 0 )
-        {
-            ifMetricSecs = atoi( curParam -> value );
-         }
-
-        /*
-         * Default: signals an error condition.
-         */
-        else
-        {
-            exit( EXIT_FAILURE ); 
-         }
-
-        curParam = curParam -> next;
-     }
+    ifMetricSecs = atoi( curParam -> value );
 
     /*
      * Daemon initialization.
@@ -530,11 +492,6 @@ int main( int argc, char **argv )
         exit( EXIT_FAILURE );
      }
 
-    /*
-     * We caught SIGINT or SIGTERM and exited evtLoop().
-     * Initiate program cleanu, and subsequent shutdown.
-     */
-
     /*
      * Remove the /tmp/.ifchk.pid write lock and then delete the file.
      */
